@@ -6,7 +6,7 @@ QUERY__fetch_email_template_by_name = "SELECT * FROM jaaql__email_template WHERE
 QUERY__make_user_public = "UPDATE jaaql__user SET public_credentials = concat(:username::text, ':', :new_password::text), application = :application, is_public = TRUE WHERE deleted is null AND id = :user_id"
 QUERY__fetch_url_from_application_name = "SELECT url FROM jaaql__application WHERE name = :application"
 QUERY__fetch_application_public_user_credentials = "SELECT split_part(public_credentials, ':', 1) as username, split_part(public_credentials, ':', 2) as password FROM jaaql__user WHERE application = :application"
-QUERY__fetch_application_default_templates = "SELECT jet.name as template, jet2.name as existing_user_template, jet3.name as default_reset_password_template FROM jaaql__application ja LEFT JOIN jaaql__email_template jet ON jet.id = ja.default_email_signup_template AND jet.deleted is NULL LEFT JOIN jaaql__email_template jet2 ON jet2.id = ja.default_email_already_signed_up_template AND jet2.deleted is NULL LEFT JOIN jaaql__email_template jet3 ON jet3.id = ja.default_forgot_password_template AND jet3.deleted is NULL WHERE ja.name = :application"
+QUERY__fetch_application_default_templates = "SELECT jet.name as template, jet2.name as existing_user_template, jet3.name as default_reset_password_template FROM jaaql__application ja LEFT JOIN jaaql__email_template jet ON jet.id = ja.default_email_signup_template AND jet.deleted is NULL LEFT JOIN jaaql__email_template jet2 ON jet2.id = ja.default_email_already_signed_up_template AND jet2.deleted is NULL LEFT JOIN jaaql__email_template jet3 ON jet3.id = ja.default_reset_password_template AND jet3.deleted is NULL WHERE ja.name = :application"
 QUERY__my_roles = "SELECT rolname FROM pg_roles WHERE pg_has_role(oid, 'member');"
 QUERY__grant_role = "GRANT \"%s\" TO \"%s\""
 QUERY__default_roles_sel = "SELECT * FROM jaaql__default_role"
